/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import java.util.Calendar;
import java.util.Date;

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.database.SQLException;
import android.util.Log;
import android.view.View;
import android.widget.RemoteViews;

public class AppWidget_4_1 extends AppWidgetProvider {

    private static final String LOGTAG = AppWidget_4_1.class.getName();
    
    @Override
    public void onUpdate(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds) {
        Log.d(LOGTAG, "In onUpdate");
        updateWidgets(context, false);
        Log.d(LOGTAG, "Leaving onUpdate");
    }
    
    @Override
    public void onReceive(Context context, Intent intent){
        Log.d(LOGTAG, "In onReceive");
        super.onReceive(context, intent);
        String action = intent.getAction();
        Log.d(LOGTAG, "Intent action:" + action);
        if(action.contentEquals(InfoFetchService.UPDATE_INTENT)){
            boolean updateInProgress = (intent.getStringExtra(InfoFetchService.UPDATE_INTENT_EXTRA_STATUS) != null);
            updateWidgets(context, updateInProgress);
        }
        Log.d(LOGTAG, "Leaving onReceive");
    }
    
    private static void updateWidgets(Context context, boolean updateInProgress){
        Log.d(LOGTAG, "In updateWidgets");
        int layout;
        
        if (updateInProgress)
            layout = R.layout.appwidget_layout_4_1_progress;
        else
            layout = R.layout.appwidget_layout_4_1;
        
        RemoteViews views = new RemoteViews(context.getPackageName(), layout);
        
        Intent overviewIntent = new Intent(context, OverviewActivity.class);
        PendingIntent pendingOverviewIntent = PendingIntent.getActivity(context, 0, overviewIntent, 0);
        views.setOnClickPendingIntent(R.id.ButtonShowOverview, pendingOverviewIntent);
        
        Intent updateSettingIntent = new Intent(context, AutoUpdateSettingActivity.class);
        PendingIntent pendingUpdateSettingIntent = PendingIntent.getActivity(context, 0, updateSettingIntent, 0);
        views.setOnClickPendingIntent(R.id.ButtonUpdate, pendingUpdateSettingIntent);
        
        writeInfoFromDb(views, context);
        
        // Push update for this widget to the home screen
        ComponentName thisWidget = new ComponentName(context, AppWidget_4_1.class);
        AppWidgetManager manager = AppWidgetManager.getInstance(context);
        manager.updateAppWidget(thisWidget, views);
        Log.d(LOGTAG, "Leaving updateWidgets");
    }

    private static void writeInfoFromDb(RemoteViews views, Context context) {
        Log.d(LOGTAG, "In writeInfoFromDb");
        InfoDbAdapter adapter = new InfoDbAdapter(context);
        try {
            adapter.open();
            int numberOfMessages = adapter.getNumberOfMessages();
            int numberOfUnread = adapter.getNumberOfUnreadSituations();
            String messageText = "";
            boolean infoExists = false;
            
            if (numberOfMessages >= 1){
                TrafficInfo newest = adapter.getNewest();
                if (newest != null){
                    messageText = newest.getHeaderWithRoadname();
                    infoExists = true;    
                    Date endTime = newest.getTo();
                    Date nextMidnight = getNextMidnight();
                    Date nextUpdateNeeded;
                    
                    if (endTime != null && endTime.getTime() < nextMidnight.getTime())
                        nextUpdateNeeded = endTime;
                    else
                        nextUpdateNeeded = nextMidnight;
                    
                    Date five = getFiveMinutes();
                    
                    if (nextUpdateNeeded.getTime() < five.getTime())
                        nextUpdateNeeded = five;

                    AutoUpdate.addPendingUpdateIntent(nextUpdateNeeded, context);
                }
            }
            
            Date updateTime = adapter.getUpdateTimestamp();
            
            String status = context.getResources().getString(
                    R.string.status_updated)
                    + " ";
            DateFormatter formatter = new DateFormatter("yyyy-MM-dd", "HH:mm");
            status += formatter.FormatTimestamp(updateTime);
            
            views.setViewVisibility(R.id.TextViewMessage, infoExists ? View.VISIBLE : View.GONE);
            views.setViewVisibility(R.id.TextViewNumber, infoExists ? View.VISIBLE : View.INVISIBLE);
            views.setViewVisibility(R.id.TextViewNoMessage, infoExists ? View.GONE : View.VISIBLE);
            
            views.setTextViewText(R.id.TextViewMessage, messageText);
            views.setTextViewText(R.id.TextViewNumber, numberOfUnread + "/" + numberOfMessages);
            views.setTextViewText(R.id.TextViewStatus, status);
        } catch (SQLException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            Log.e(LOGTAG, "SQLException writeInfoFromDb");
        } finally {
            adapter.close();
        }
        Log.d(LOGTAG, "Leaving writeInfoFromDb");
    }

    private static Date getNextMidnight() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        calendar.roll(Calendar.DATE, true);
        calendar.set(Calendar.HOUR_OF_DAY, 0);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        return calendar.getTime();
    }    
    
    private static Date getFiveMinutes() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        calendar.roll(Calendar.MINUTE, 5);
        return calendar.getTime();
    }
}

