/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import java.util.Date;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.util.Log;

public class AutoUpdate extends BroadcastReceiver {

    private static final String LOGTAG = AutoUpdate.class.getName();
    private static final String UPDATE_INTENT = "se.peterbjorkman.android.trafikinfo.reccuringupdate";
    
    @Override
    public void onReceive(Context context, Intent intent){
        Log.d(LOGTAG, "In onReceive");
        String action = intent.getAction();
        Log.d(LOGTAG, "Intent action:" + action);
        if (action.contentEquals(UPDATE_INTENT)){
            InfoFetchService.acquireStaticLock(context);
            context.startService(new Intent(context, InfoFetchService.class));
        } else if (action.contentEquals("android.intent.action.BOOT_COMPLETED")){
            updateUpdateAlarmManger(context);
        }
        Log.d(LOGTAG, "Leaving onReceive");
    }
    
    public static void addPendingUpdateIntent(Date time, Context context){
        Intent updateIntent = new Intent(InfoFetchService.UPDATE_INTENT);
        
        PendingIntent pendingIntent = PendingIntent.getBroadcast(context, 0, updateIntent, PendingIntent.FLAG_CANCEL_CURRENT);

        AlarmManager alarmManager = getAlarmManager(context);
        alarmManager.set(
                AlarmManager.RTC,
                time.getTime() , 
                pendingIntent);
    }
    
    public static void updateUpdateAlarmManger(Context context) {
        Log.d(LOGTAG, "In updateUpdateAlarmManger");
        
        String preferenceKey = context.getString(R.string.autoUpdateKey);
        String defaultUpdateValue = context.getString(R.string.defaultAutoUpdateMode);
        
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(context);
        String currentValue = prefs.getString(preferenceKey, defaultUpdateValue);
        
        String[] modes = context.getResources().getStringArray(R.array.autoUpdateModes);
        
        if (modes.length != 3)
            Log.e(LOGTAG, "wrong number of modes in R.array.autoUpdateModes");
        
        String autoUpdateModeNever  = modes[0];
        String autoUpdateModeLong = modes[2];
        
        stopUpdateAlarmManger(context);
        String intervalPreferenceKey;
        String defaultInterval;
        
        if (currentValue.contentEquals(autoUpdateModeNever)){
            Log.d(LOGTAG, "update mode is never abort after stopping alarmmanager");
            return;
        } else if (currentValue.contentEquals(autoUpdateModeLong)){
            intervalPreferenceKey = context.getString(R.string.longIntervalKey);
            defaultInterval = context.getString(R.string.DefaultLongInterval);
        }
        else{
            intervalPreferenceKey = context.getString(R.string.shortIntervalKey);
            defaultInterval = context.getString(R.string.DefaultShortInterval);
        }            
        
        String periodString = prefs.getString(intervalPreferenceKey, defaultInterval);
        
        long period;
        
        try {
            period = Integer.parseInt(periodString);
        } catch (NumberFormatException e) {
            Log.e(LOGTAG, "Could not parse periodString " + periodString);
            Log.d(LOGTAG, "Use 60 minutes as period");
            period = 60;
        }
        
        Log.d(LOGTAG, "Period = " + period);
        Log.d(LOGTAG, "CurrentValue = " + currentValue);
        
        if (period == 15)
            period = AlarmManager.INTERVAL_FIFTEEN_MINUTES;
        else
            period = period * 60 * 1000;
        
        int triggerAtTime = 10 * 1000; // Wait 10 s
        
        PendingIntent pendingIntent = createPendingIntent(context);
        AlarmManager alarmManager = getAlarmManager(context);
        alarmManager.setInexactRepeating(
                AlarmManager.ELAPSED_REALTIME_WAKEUP,
                triggerAtTime , 
                period, 
                pendingIntent);
        Log.d(LOGTAG, "Leaving updateUpdateAlarmManger");
    }

    private static AlarmManager getAlarmManager(Context context) {
        return (AlarmManager)context.getSystemService(Context.ALARM_SERVICE);
    }

    private static PendingIntent createPendingIntent(Context context) {
        
        Intent updateIntent = new Intent(UPDATE_INTENT);
        
        PendingIntent pendingIntent = PendingIntent.getBroadcast(context, 0, updateIntent, PendingIntent.FLAG_CANCEL_CURRENT);
        return pendingIntent;
    }
    
    private static void stopUpdateAlarmManger(Context context) {
        Log.d(LOGTAG, "In stopUpdateAlarmManger");
        
        PendingIntent pendingIntent = createPendingIntent(context);
        AlarmManager alarmManager = getAlarmManager(context);
        alarmManager.cancel(pendingIntent);
        
        Log.d(LOGTAG, "Leaving stopUpdateAlarmManger");
    }
}

