/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import android.app.Activity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.content.res.Resources;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.AdapterView.OnItemClickListener;

public class AutoUpdateSettingActivity extends Activity {
    private static final String LOGTAG = AutoUpdateSettingActivity.class.getName();
    
    private String[] choices;
    String preferenceKey;
    SharedPreferences prefs;
    private ListView mlistView;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        Log.d(LOGTAG, "in onCreate");
        super.onCreate(savedInstanceState);

        setContentView(R.layout.widget_update_choice);
        
        choices = getResources().getStringArray(R.array.autoUpdateModes);

        final ListView listView = (ListView)findViewById(R.id.ListViewAutoUpdate);
        mlistView = listView;
        
        presentCurrentSettings();
        
       prefs.registerOnSharedPreferenceChangeListener(new OnSharedPreferenceChangeListener() {
            
            @Override
            public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
                    String key) {
                Log.d(LOGTAG, "in prefs.onSharedPreferenceChanged");
                if (key.contentEquals(preferenceKey)){
                    Log.d(LOGTAG, "in prefs.onSharedPreferenceChanged key match");
                    AutoUpdate.updateUpdateAlarmManger(AutoUpdateSettingActivity.this);
                }
            }
        });

        
        listView.setOnItemClickListener(new OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                Log.d(LOGTAG, "in listView.onItemClick");
                String preferenceKey = AutoUpdateSettingActivity.this.preferenceKey;
                String preferenceValue = AutoUpdateSettingActivity.this.choices[position];
                SharedPreferences.Editor editor = AutoUpdateSettingActivity.this.prefs.edit();
                editor.putString(preferenceKey, preferenceValue);
                editor.commit();
                
                finish();
            }
        });
        
        Button updateNowButton = (Button) findViewById(R.id.ButtonUpdate);
        updateNowButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                Log.d(LOGTAG, "in updateNowButton.onClick");
                finish();
                startService(new Intent(AutoUpdateSettingActivity.this, InfoFetchService.class));
            }
        });
        
        Button moreSettingsButton = (Button) findViewById(R.id.ButtonSettings);
        moreSettingsButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                Log.d(LOGTAG, "in moreSettingsButton.onClick");
                startActivityForResult(new Intent(AutoUpdateSettingActivity.this, TrafikinfoPreferencesActivity.class), 0);
                // TODO update text if long or short intervall is changed. Also update current mode if changed.
                presentCurrentSettings();
            }
        });
    }
    
    @Override
    protected void onActivityResult (int requestCode, int resultCode, Intent data){
        Log.d(LOGTAG, "in onActivityResult");
        super.onActivityResult(requestCode, resultCode, data);
        presentCurrentSettings();
    }

    private void presentCurrentSettings() {
        Log.d(LOGTAG, "in presentCurrentSettings");
        final ListView listView = mlistView;
        listView.setAdapter(new ArrayAdapter<String>(this,
                android.R.layout.simple_list_item_single_choice, choices));
           
        listView.setItemsCanFocus(false);
        listView.setChoiceMode(ListView.CHOICE_MODE_SINGLE);
        Resources resources = getResources();

        prefs = PreferenceManager.getDefaultSharedPreferences(this);
        preferenceKey = resources.getString(R.string.autoUpdateKey);
        
        String defaultValue = resources.getString(R.string.defaultAutoUpdateMode);
        String currentValue = prefs.getString(preferenceKey, defaultValue);
        
        int i = 0;
        for (; i < choices.length; i++)
            if (choices[i].contentEquals(currentValue))
                break;
        
        listView.setItemChecked(i, true);
    }
}
