/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import java.text.SimpleDateFormat;
import java.util.Date;

public class DateFormatter {
    private static final String LOGTAG = Logger.createLogtag(DateFormatter.class);
    
    private SimpleDateFormat mTimeFormater;
    private SimpleDateFormat mDateFormater;

    public DateFormatter(String dateFormat, String timeFormat) {
        Logger.d(LOGTAG, "In Construtor dateFormat = " + dateFormat + " timeFormat = " + timeFormat);
        mTimeFormater = new SimpleDateFormat(timeFormat);
        mDateFormater = new SimpleDateFormat(dateFormat);
    }

    public String FormatPeriod(Date from, Date to) {
        Logger.d(LOGTAG, "In FormatPeriod");
        if (from == null && to == null){
            Logger.d(LOGTAG, "FormatPeriod return okänd tisperiod");
            return "okänd tidsperiod"; //TODO Hardcoded string
        }
            
        
        String ret = "";
        if (from == null)
            ret += "till ";
        else
            ret += formatDate(from) + " " + mTimeFormater.format(from);

        Logger.d(LOGTAG, "FormatPeriod from = " + ret);
        
        if (to == null){
            Logger.d(LOGTAG, "to is tillsvidare ");
            return ret + " tillsvidare"; //TODO Hardcoded string   
        }

        ret += " - ";

        if (DiffDate(from, to) != 0)
            ret += formatDate(to) + " ";

        ret += mTimeFormater.format(to);

        Logger.d(LOGTAG, "FormatPeriod returns " + ret);
        return ret;
    }

    public String FormatTimestamp(Date timestamp) {
        Logger.d(LOGTAG, "in FormatTimestamp");
        if (timestamp == null)
            return "Okänd tid"; //TODO Hardcoded string
        return formatDate(timestamp) + " " + mTimeFormater.format(timestamp);
    }

    private String formatDate(Date date) {
        Logger.d(LOGTAG, "in formatDate");
        int diffDays = DiffDate(date, new Date());
        if (diffDays == 0){
            Logger.d(LOGTAG, "formatDate return today");            
            return "idag";
        }
        if (diffDays == 1){
            Logger.d(LOGTAG, "formatDate return tomorrow");
            return "imorgon";   
        }
        if (diffDays == -1){
            Logger.d(LOGTAG, "formatDate return yesterday");
            return "igår";
        }
        Logger.d(LOGTAG, "formatDate returns formatted date");
        return mDateFormater.format(date);
    }

    private int DiffDate(Date d1, Date d2) {
        Logger.d(LOGTAG, "in formatDate");
        Date d1d = new Date(d1.getYear(), d1.getMonth(), d1.getDate());
        Date d2d = new Date(d2.getYear(), d2.getMonth(), d2.getDate());
        long miliseconds = d1d.getTime() - d2d.getTime();
        Logger.d(LOGTAG, "milliseconds in formatDate = " + miliseconds);
        return (int) (miliseconds / (long) (60 * 60 * 24 * 1000));

    }
}