/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import android.app.TabActivity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TabHost;

public class DetailedActivity extends TabActivity {
    private static final String LOGTAG = DetailedActivity.class.getName();
    
    private static final int MENU_DELETE_ID = Menu.FIRST;
    private TrafficInfo mInfo;
    
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.d(LOGTAG, "in onCreate");
        
        super.onCreate(savedInstanceState);

        final Intent intent = getIntent();
        final TabHost tabHost = getTabHost();
        final TrafficInfo info = (TrafficInfo) intent.getExtras()
            .getSerializable(DetailedInfoActivity.INTENTEXTRA_INFO);
        
        mInfo = info;

        // TODO Hardcoded strings
        Intent infoIntent = new Intent(this, DetailedInfoActivity.class);
        infoIntent.putExtras(intent.getExtras());
        tabHost.addTab(tabHost.newTabSpec("tab1")
                .setIndicator("Information")
                .setContent(infoIntent));
        
        if (info.getLongitude() != 0 && info.getLatitude() != 0){
            Log.d(LOGTAG, "add map tab in onCreate");
            
            Intent mapIntent = new Intent(this, DetailedMapActivity.class);
            mapIntent.putExtra(DetailedMapActivity.INTENTEXTRA_SITUATION_ID, info.getExternalId());
            
            tabHost.addTab(tabHost.newTabSpec("tab2")
                .setIndicator("Karta")
                .setContent(mapIntent));
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        Log.d(LOGTAG, "In onCreateOptionsMenu");
        
        boolean result = super.onCreateOptionsMenu(menu);

        menu.add(0, MENU_DELETE_ID, 0, R.string.deleteMessage)
            .setIcon(android.R.drawable.ic_menu_delete);
        
        return result;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        Log.d(LOGTAG, "In onOptionsItemSelected");
        
        switch (item.getItemId()) {
        case MENU_DELETE_ID:
            markDeleted();
            finish();
            return true;
        }
        
        return super.onOptionsItemSelected(item);
    }

    private void markDeleted() {
        // TODO error handling
        String  externalId = mInfo.getExternalId();
        Context context = getBaseContext();
        InfoDbAdapter dbAdapter = new InfoDbAdapter(context);
        dbAdapter.open();
        Long id = dbAdapter.getIdByExternalId(externalId); 
        dbAdapter.markSiuationDeleted(id, context);
        dbAdapter.close();
    }
}
