/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;

public class DetailedInfoActivity extends Activity {
    private static final String LOGTAG = DetailedInfoActivity.class.getName();
    
    public static final String INTENTEXTRA_INFO = "info";
    public static final String INTENTEXTRA_MARKREAD = "markread";

    @Override
    public void onCreate(Bundle savedInstanceState) {
        Log.d(LOGTAG, "In onCreate");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.det);
        final TrafficInfo info = (TrafficInfo) getIntent().getExtras()
                .getSerializable(INTENTEXTRA_INFO);
        
        Boolean shouldMarkRead = getIntent().getExtras().getBoolean(INTENTEXTRA_MARKREAD, false);
        
        if (shouldMarkRead)
            markSituationRead(info.getExternalId());
        else
            Log.d(LOGTAG, "in onCreate shouldMarkAsRead is false");

        TextView textView1 = (TextView) findViewById(R.id.TitleTextView);
        textView1.setText(info.getHeader());
        TextView typeTextView = (TextView) findViewById(R.id.TypeTextView);
        typeTextView.setText(info.getTypeName());
 
        String message = "";
        List<String> comments = info.getComments();
        int numberOfComments = comments.size();
        
        if (numberOfComments > 0)
            message = comments.get(0);
        
        setInfo(R.id.InfoBlockMessage, R.string.message, message);
        
        if (numberOfComments > 1){
            InfoBlock messageBlock = (InfoBlock)findViewById(R.id.InfoBlockMessage);
            for (int i = 1 ; i < numberOfComments; i++)
                messageBlock.addExtraText(comments.get(i), this);
        }
        
        setInfo(R.id.InfoBlockPosition, R.string.position, info.getLocation());
        setInfo(R.id.InfoBlockRoad, R.string.road, info
                .getRoad());

        DateFormatter formatter = new DateFormatter("yyyy-MM-dd", "HH:mm");
        setInfo(R.id.InfoBlockPeriod, R.string.period, formatter.FormatPeriod(
                info.getFrom(), info.getTo()));
        
        setInfo(R.id.InfoBlockSource, R.string.source, info.getSource());
        setInfo(R.id.InfoBlockModified, R.string.lastModified, formatter.FormatTimestamp(info.getModified()));

        List<Restriction> restrictions = info.getRestricions();
        int numberOfRestrictions = restrictions.size(); 
        
        LinearLayout restrictionLayout = (LinearLayout)findViewById(R.id.LinearLayoutRestriction);
        
        for (int i = 0; i < numberOfRestrictions; i++){
            Restriction restriction = restrictions.get(i);
            InfoBlock test = new InfoBlock(this);

            test.setTitleText(restriction.getTypeName());
            
            test.setInfoText("");
            
            List<String> restrictionComments = restriction.getComments();
            int numberOfRestrictionComments = restrictionComments.size();
            
            for (int j=0; j < numberOfRestrictionComments; j++)
                test.addText(restrictionComments.get(j), this);

            int speedLimit = restriction.getSpeedLimit();
            if (speedLimit != 0){
                String speedLimitText = speedLimit + " km/h";
                test.addText(speedLimitText, this);
            }
            
            Date from = restriction.getFrom();
            Date to = restriction.getTo();
            if (from != null || to != null)
                test.addText(formatter.FormatPeriod(from, to), this);
                
            restrictionLayout.addView(test);
        }

        Log.d(LOGTAG, "Leaving onCreate");
    }
    
    private void markSituationRead(String externalId){
        Log.d(LOGTAG, "in markSituationRead");
        Log.d(LOGTAG, "in markSituationRead. ExternalID = " + externalId);
        InfoDbAdapter adapter = new InfoDbAdapter(this);
        try{
            adapter.open();
            long id = adapter.getIdByExternalId(externalId);
            List<Long> list = new ArrayList<Long>(1);
            list.add(id);
            adapter.markSiuationsAsRead(list, this);
        } finally {
            adapter.close();
        }
    }

    private void setInfo(int infoBlockId, int headingStringId, String infoText) {
        Log.d(LOGTAG, "In setInfo");
        InfoBlock restrictionBlock = (InfoBlock) findViewById(infoBlockId);

        if (infoText == null || infoText.contentEquals(""))
            restrictionBlock.setVisibility(View.GONE);
        else {
            restrictionBlock.setTitleText(getResources().getString(
                    headingStringId));
            restrictionBlock.setInfoText(infoText);
        }
    }
}