/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import android.database.Cursor;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;

public class DetailedMapActivity extends AutoZoomSituationMapActivity {
    private static final String LOGTAG = DetailedMapActivity.class.getName();
    public  static final String INTENTEXTRA_SITUATION_ID = "ID";
    
    private static final int LOCATION_MENU_ID = SituationMapActivity.LAST_MENU_ID_USED + 1 ;

    private String mSituationId;

    public void onCreate(Bundle savedInstanceState) {
        Log.d(LOGTAG, "In onCreate");
        mSituationId = getIntent().getStringExtra(INTENTEXTRA_SITUATION_ID);
        super.onCreate(savedInstanceState);
    }
    
    @Override
    protected Cursor getCursor(InfoDbAdapter dbAdapter) {
        return dbAdapter.fetchSituation(mSituationId);
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        Log.d(LOGTAG, "In onCreateOptionsMenu");
        
        boolean result = super.onCreateOptionsMenu(menu);

        menu.add(0, LOCATION_MENU_ID, 0, R.string.situationLocation)
            .setIcon(android.R.drawable.ic_menu_mylocation);
        
        return result;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        Log.d(LOGTAG, "In onOptionsItemSelected");
        
        switch (item.getItemId()) {
        case LOCATION_MENU_ID:
            panToSituationLocation();
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    private void panToSituationLocation() {
        Log.d(LOGTAG, "In panToSituationLocation");
        SituationMapOverlay itemizedoverlay = getItemizedoverlay();
        
        if (itemizedoverlay.size() <= 0)
            return;
        
        SituationOverlayItem item = itemizedoverlay.getItem(0);
        setCenter(item.getPoint());
    }
}
