/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2009-2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo.Exceptions;

import se.peterbjorkman.android.trafikinfo.R;

public class FetchInfoException extends Exception {
    private static final long serialVersionUID = 1433073919372238243L;

    private String mUrl;
    private ErrorCodes mErrorCode;

    public enum ErrorCodes {
        IOError, 
        DataFormatError, 
        HttpError, 
        ServerApiVersionError,
        DatabaseError
    }

    public String getUrl() {
        return mUrl;
    }

    public ErrorCodes getErrorCode() {
        return mErrorCode;
    }

    public int getStringID() {
        switch (mErrorCode) {
        case IOError:
            return R.string.FetchInfoException_IOError;
        case ServerApiVersionError:
            return R.string.FetchInfoException_ApiError;
        case HttpError:
            return R.string.FetchInfoException_HttpError;
        case DataFormatError:
            return R.string.FetchInfoException_FormatError;
        case DatabaseError:
            return R.string.FetchInfoException_SQLError;
        }
        return R.string.FetchInfoException_UndefinedError;
    }

    public FetchInfoException(String url, ErrorCodes errorCode,
            Exception innerException) {
        super(innerException);
        mUrl = url;
        mErrorCode = errorCode;
    }

    public FetchInfoException(String url, ErrorCodes errorCode) {
        mUrl = url;
        mErrorCode = errorCode;
    }

}
