/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2009-2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import se.peterbjorkman.android.trafikinfo.Exceptions.FetchInfoException;

public interface IDataObserver {

    /**
     * Indicates progress of the background thread to the user.
     * <p>
     * The method is safe to call from any thread.
     * 
     * @param status
     *            Text that should be written to the stus field
     * @param done
     *            How much of the total work that is completed
     * @param total
     *            A value indicating how much work is to be done.
     */
    public void setStatus(String status, int done, int total);

    /**
     * Called when the service has made a complete update
     * 
     * @param timeStamp
     *            The time the items were downloaded
     */
    public void completeDataUpdateDone();

    /**
     * Called when an error occurred while the service eas updating data.
     */
    public void errorEncountered(FetchInfoException e);
}
