package se.peterbjorkman.android.trafikinfo;

import java.util.Date;

import android.content.Context;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.util.Log;

public class LocationRetriever {
    private static final String LOGTAG = LocationRetriever.class.getName();
    
    private final Boolean mPreferGps;
    private final int mMaxWaitTime;
    private final int mMaxLocationAge;
    private final int mMinGpsAccuracy;
    
    public LocationRetriever(Boolean useGps, int maxWaitTime, int maxLocationAge, int minGpsAccuracy)
    {
        mPreferGps = useGps;
        mMaxWaitTime = maxWaitTime;
        mMaxLocationAge = maxLocationAge;
        mMinGpsAccuracy = minGpsAccuracy;        
    }
    
    public Location getCurrentLocation(Context context) {
        Log.d(LOGTAG, "In getCurrentLocation");
        final LocationManager locMan = (LocationManager) context.getSystemService(Context.LOCATION_SERVICE);

        Long startTimestamp = new Date().getTime();
        
        Location location;
        
        Location lastGpsLocation = locMan.getLastKnownLocation(LocationManager.GPS_PROVIDER);
        Location lastNetworkLocation = locMan.getLastKnownLocation(LocationManager.NETWORK_PROVIDER);
        
        final Boolean useGps = mPreferGps && locMan.isProviderEnabled(LocationManager.GPS_PROVIDER);
        
        if (isLocationOk(startTimestamp, lastGpsLocation, useGps)){
            Log.d(LOGTAG, "Use last GPS location");
            location = lastGpsLocation;
        } else if (isLocationOk(startTimestamp, lastNetworkLocation, useGps)) {
            Log.d(LOGTAG, "Use last Network location");
            location = lastNetworkLocation;
        } else {
            Log.d(LOGTAG, "Retrive location from providers");
            location = getLocationFromProviders(locMan, startTimestamp, useGps);
        }
        
        if (location != null)
        {
            Log.d(LOGTAG, "Location is " + location.toString());
            Date date = new Date(location.getTime());
            Log.d(LOGTAG, "Location time stamp is " + date.toString());
        } else {
            Log.w(LOGTAG, "Location is null");
        }
        
        return location;
    }

    private Location getLocationFromProviders(final LocationManager locMan, Long startTimestamp, Boolean useGps) {
        Log.d(LOGTAG, "IngetLocationFromProviders");
        
        LocationListener listener = new LocationListener() {
            
            @Override
            public void onStatusChanged(String provider, int status, Bundle extras) {   
            }
            
            @Override
            public void onProviderEnabled(String provider) {
            }
            
            @Override
            public void onProviderDisabled(String provider) {
            }
            
            @Override
            public void onLocationChanged(Location changedLocation) {

            }
        };

        final String gps = LocationManager.GPS_PROVIDER;
        final String network = LocationManager.NETWORK_PROVIDER;
        
        locMan.requestLocationUpdates(network, 0, 0, listener);
        
        final int sleepTime = 500;
        
        Location location = null;

        final int maxWaitTime = mMaxWaitTime;
        for (int i = 0; i < maxWaitTime; i+= sleepTime) {
            if (i > 0 && useGps)
                locMan.requestLocationUpdates(gps, 0, 0, listener);
            
            if (useGps){
                location = locMan.getLastKnownLocation(gps);
                if (isLocationOk(startTimestamp, location, useGps))
                    break;
            }
            
            location = locMan.getLastKnownLocation(network);
            if (isLocationOk(startTimestamp, location, useGps))
                break;
            
            try {
                Thread.sleep(sleepTime);
            } catch (InterruptedException e) {
            }
        }
        
        locMan.removeUpdates(listener);
        
        if (!isLocationOk(startTimestamp, location, true) && useGps)
            location = locMan.getLastKnownLocation(network); // TODO Is the network location better?
        
        if (!isLocationOk(startTimestamp, location, false))
            location = null;
        
        return location;
    }

    private boolean isLocationOk(Long time, Location location, Boolean checkAccuracy) {
        if (location == null)
            return false;
        
        Boolean tooOld = time - location.getTime() > mMaxLocationAge;
        
        Boolean isAccurate = !checkAccuracy || location.getAccuracy() < mMinGpsAccuracy;
        
        return !tooOld && isAccurate;
    }
}

