/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package se.peterbjorkman.android.trafikinfo;

import android.app.AlertDialog;
import android.app.Dialog;
import android.app.TabActivity;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.DialogInterface.OnClickListener;
import android.content.pm.PackageManager.NameNotFoundException;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.TabHost;
import android.widget.TextView;
import android.net.Uri;
import android.os.Bundle;

public class OverviewActivity extends TabActivity {
    private static final String LOGTAG = OverviewActivity.class.getName();
    
    private static final int UPDATE_MENU_ID = Menu.FIRST;
    private static final int SETTINGS_MENU_ID = UPDATE_MENU_ID + 1;
    private static final int ABOUT_MENU_ID = SETTINGS_MENU_ID +1;
    private static final int SWITCH_PROFILE_MENU_ID = ABOUT_MENU_ID +1;
    
    private static final int DIALOG_ABOUT = 0;
    private static final int DIALOG_WELCOME = DIALOG_ABOUT +1;
    
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        final TabHost tabHost = getTabHost();

        // TODO Hardcoded strings
        tabHost.addTab(tabHost.newTabSpec("tab1")
                .setIndicator("Pågående")
                .setContent(new Intent(this, OverviewListActivity.class)));

        tabHost.addTab(tabHost.newTabSpec("tab2")
                .setIndicator("Karta")
                .setContent(new Intent(this, MapOverviewActivity.class)));
        
        tabHost.addTab(tabHost.newTabSpec("tab3")
                .setIndicator("Planerade")
                .setContent(new Intent(this, FutureListActivity.class)));
        
        if (WelcomeDialogBuilder.ShouldBeShown(this)){
            showDialog(DIALOG_WELCOME);
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        Log.d(LOGTAG, "In onCreateOptionsMenu");
        
        boolean result = super.onCreateOptionsMenu(menu);

        menu.add(0, UPDATE_MENU_ID, 0, R.string.update)
            .setIcon(R.drawable.menu_update);
        
        menu.add(0, SETTINGS_MENU_ID, 0, R.string.settings)
            .setIcon(android.R.drawable.ic_menu_preferences);

        menu.add(0, ABOUT_MENU_ID, 0, R.string.about)
        .setIcon(android.R.drawable.ic_menu_info_details);
        
        menu.add(0, SWITCH_PROFILE_MENU_ID, 0, R.string.profile)
        .setIcon(android.R.drawable.ic_menu_manage);
        
        return result;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        Log.d(LOGTAG, "In onOptionsItemSelected");
        
        switch (item.getItemId()) {
        case UPDATE_MENU_ID:
            startService(new Intent(this, InfoFetchService.class));
            return true;
        case SETTINGS_MENU_ID:
            Intent launchIntent = new Intent(OverviewActivity.this,
                    TrafikinfoPreferencesActivity.class);
            OverviewActivity.this.startActivity(launchIntent);
            return true;
        case ABOUT_MENU_ID:
            showDialog(DIALOG_ABOUT);
            return true;
        case SWITCH_PROFILE_MENU_ID:
            Intent profileLaunchIntent = new Intent(OverviewActivity.this,
                    AutoUpdateSettingActivity.class);
            OverviewActivity.this.startActivity(profileLaunchIntent);
            return true;
        }
        
        return super.onOptionsItemSelected(item);
    }
    

    @Override
    protected Dialog onCreateDialog(int id) {
        Log.d(LOGTAG, "In onCreateDialog");
        switch (id) {
            case DIALOG_ABOUT: {
                AlertDialog.Builder d = new AlertDialog.Builder(this);
                d.setTitle(getString(R.string.about) + " " + getString(R.string.app_name) + " " + getVersion());
                d.setIcon(android.R.drawable.ic_menu_info_details);
                d.setPositiveButton(R.string.aboutHomepage, new OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        Uri uri = Uri.parse(getString(R.string.aboutHomepageUrl));
                        startActivity(new Intent(Intent.ACTION_VIEW, uri));
                    }
                });
    //            d.setNeutralButton(R.string.aboutDonation, new OnClickListener() {
    //                public void onClick(DialogInterface arg0, int arg1) {
    //                    Uri uri = Uri.parse(getString(R.string.aboutDonationUrl));
    //                    startActivity(new Intent(Intent.ACTION_VIEW, uri));
    //                }
    //            });
                d.setNegativeButton(R.string.closeString, null);
                View v = LayoutInflater.from(this).inflate(R.layout.about, null);
                
                final int size = 12;
                
                TextView generalTextView = (TextView) v.findViewById(R.id.AboutText);
                generalTextView.setText(getString(R.string.aboutTextGeneral));
                generalTextView.setTextSize(size);
                
                InfoBlock blockSource = (InfoBlock) v.findViewById(R.id.InfoBlockSource);
                blockSource.setTitleText(getString(R.string.aboutTitleSource));
                blockSource.setInfoText(getString(R.string.aboutTextSource));
                blockSource.SetInfoTextSize(size);
                
                InfoBlock blockLicense = (InfoBlock) v.findViewById(R.id.InfoBlockDeveloper);
                blockLicense.setTitleText(getString(R.string.aboutTitleLicense));
                String text = getString(R.string.aboutTextLicenseIntro) + "\n";
                blockLicense.setInfoText(text);
                blockLicense.SetInfoTextSize(size);
                blockLicense.setUseLinks(false);
                
                text = getString(R.string.aboutTextLicenseSource);
                blockLicense.addExtraText(text, OverviewActivity.this, false);
                
                text = getString(R.string.aboutTextLicenseCopyright);
                blockLicense.addExtraText(text, OverviewActivity.this, false);
                
                text = getString(R.string.aboutTextLicenseGPLNoWarranty);
                blockLicense.addExtraText(text, OverviewActivity.this, false);
                
                text = getString(R.string.aboutTextLicenseGPLDistribute);
                blockLicense.addExtraText(text, OverviewActivity.this, false);
                
                text = getString(R.string.aboutTextLicenseGPLDetails);
                blockLicense.addExtraText(text, OverviewActivity.this, false);
                
                text = getString(R.string.aboutTextLicenseGPLDetailsURL);
                blockLicense.addExtraText(text, OverviewActivity.this, true);
                
                d.setView(v);
                
                Log.d(LOGTAG, "Returning from onCreateDialog");
                
                return d.create();
            }
            case DIALOG_WELCOME: {
                WelcomeDialogBuilder builder = new WelcomeDialogBuilder(this);
                return builder.getWelcomeDialog();
            }
        }
        Log.d(LOGTAG, "Returning null from onCreateDialog");
        return null;
    }

    private String getVersion() {
        Log.d(LOGTAG, "In getVersion");
        try {
            return getPackageManager().getPackageInfo(getPackageName(), 0).versionName;
        } catch (NameNotFoundException e) {
            Log.e(LOGTAG, "NameNotFoundException in  getVersion " + e.getLocalizedMessage());
            // Ignore.
        }
        Log.w(LOGTAG, "Returning empty string from getVersion");
        return "";
    }
}
