package se.peterbjorkman.android.trafikinfo;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.util.Log;

public class PreferenceHandler {
    private static final String LOGTAG = PreferenceHandler.class.getName();
    
    public static final Byte NOTIFICATIONLEVEL_NOTHING = 0;
    public static final Byte NOTIFICATIONLEVEL_ICON = 1;
    public static final Byte NOTIFICATIONLEVEL_ICONANDSOUND = 2;
    public static final Byte NOTIFICATIONLEVEL_ICONSOUNDANDLED = 3;
    
    public enum UpdateProfile{
        Never,
        Update,
        Traffic,
    }
    
    public byte getNoticifationLevel(Context context){
        Log.d(LOGTAG, "in getNoticifationLevel");
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(context);
        
        UpdateProfile profile = getUpdateProfile(context, prefs);
        
        String notificationPreferenceKey;
        String defaultNotification;

        switch (profile){
        case Never:
            Log.d(LOGTAG, "in Profile is manual return NOTIFICATIONLEVEL_NOTHING");
            return NOTIFICATIONLEVEL_NOTHING;
        case Traffic:
            notificationPreferenceKey = context.getString(R.string.trafficNotificationTypeKey);
            defaultNotification = context.getString(R.string.DefaultTrafficNotificationType);
            break;
        case Update:
            notificationPreferenceKey = context.getString(R.string.updateNotificationTypeKey);
            defaultNotification = context.getString(R.string.DefaultUpdateNotificationType);
            break;
            default:
                Log.e(LOGTAG, "Unknown profile return NOTIFICATIONLEVEL_NOTHING. Profile = " + profile);
                return NOTIFICATIONLEVEL_NOTHING;
        }

        String valString = prefs.getString(notificationPreferenceKey, defaultNotification);
        
        byte value;
        
        try {
            value = Byte.parseByte(valString);
        } catch (NumberFormatException e) {
            Log.e(LOGTAG, "Could not parse periodString " + valString);
            return NOTIFICATIONLEVEL_NOTHING;
        }
        return value;
    }

    private UpdateProfile getUpdateProfile(Context context,
            SharedPreferences prefs) {
        Log.d(LOGTAG, "in getUpdateProfile");
        String preferenceKey = context.getString(R.string.autoUpdateKey);
        String defaultUpdateValue = context.getString(R.string.defaultAutoUpdateMode);
        
        String currentValue = prefs.getString(preferenceKey, defaultUpdateValue);
        
        String[] modes = context.getResources().getStringArray(R.array.autoUpdateModes);
        
        if (modes.length != 3)
            Log.e(LOGTAG, "wrong number of modes in R.array.autoUpdateModes");
        
        String autoUpdateModeNever  = modes[0];
        String autoUpdateModeLong = modes[2];
        
        Log.d(LOGTAG, "in currentValue = " + currentValue);
        
        UpdateProfile profile;
        if (currentValue.contentEquals(autoUpdateModeNever)){
            profile = UpdateProfile.Never;
        } else if (currentValue.contentEquals(autoUpdateModeLong)){
            profile = UpdateProfile.Update;
        }
        else{
            profile = UpdateProfile.Traffic;
        }
        return profile;
    }
    
    public long getCategoryMask(Context context){
        SharedPreferences prefs = PreferenceManager
        .getDefaultSharedPreferences(context);

        long mask = 0;
        
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.ABNORMALTRAFFIC_BIT,
                R.string.categoryAbnormalTrafficKey, 
                mask);
        
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.ACCIDENT_BIT,
                R.string.categoryAccidentKey, 
                mask);
        
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.ANIMALPRESENCEOBSTRUCTION_B,
                R.string.categoryAnimalKey, 
                mask);
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.OBSTRUCTION_BIT,
                R.string.categoryObstructionKey, 
                mask);
        
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.OTHER_BIT,
                R.string.categoryOthersKey, 
                mask);
        
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.REROUTING_BIT,
                R.string.categoryReroutingKey, 
                mask);
        
        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.ROADCLOSED_BIT,
                R.string.categoryRoadClosedKey, 
                mask);

        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.ROADCONDITIONS_BIT,
                R.string.categoryRoadConditionsKey, 
                mask);

        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.ROADWORKS_BIT,
                R.string.categoryRoadWorksKey, 
                mask);

        mask = setCategoryBitIfSelected(
                context, 
                prefs, 
                CategoryResolver.TEMPORARYSPEEDLIMIT_BIT,
                R.string.categoryTemporarySpeedlimitKey, 
                mask);
        
        return mask;
    }

    private long setCategoryBitIfSelected(Context context,
            SharedPreferences prefs, int categoryBit, int keyResource, long mask) {
        String key = context.getString(keyResource);
        
        if (prefs.getBoolean(key, true))
            mask |= categoryBit;
        return mask;
    }
    
    public byte getRadius(Context context) {
        Log.d(LOGTAG, "in getRadius");

        String valString = getPreferenceString(context, R.string.radiusKey,
                R.string.defaultRadius);

        byte value;

        try {
            value = Byte.parseByte(valString);
        } catch (NumberFormatException e) {
            Log.e(LOGTAG, "Could not parse preference return 1. value:" + valString);
            value =  1;
        }
        return value;
    }

    private String getPreferenceString(
                                Context context, 
                                int keyResource,
                                int defaultValueResource) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);

        String key = context.getString(keyResource);
        String defaultValue = context.getString(defaultValueResource);

        String valString = prefs.getString(key, defaultValue);
        return valString;
    }

    private boolean getPreferenceBool(
                                Context context, 
                                int keyResource,
                                boolean defaultValue) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);

        String key = context.getString(keyResource);

        return prefs.getBoolean(key, defaultValue);
    }

    public boolean getUseGps(Context context) {
        return getPreferenceBool(context, R.string.useGpsKey, false);
    }
}
