package se.peterbjorkman.android.trafikinfo;

import java.util.ArrayList;
import java.util.List;

import se.peterbjorkman.android.trafikinfo.TrafficInfo.ReadState;
import android.util.Log;

public class SituationHandler implements ISituationHandler {
    private static final String LOGTAG = InfoFetchService.class.getName();

    private final InfoDbAdapter mDbAdapter;
    private final long mCategoryMask;
    final List<String> mChangesIdsList = new ArrayList<String>();
    
    public SituationHandler(InfoDbAdapter dbAdapter, long categoryMask){
        mDbAdapter = dbAdapter;
        mCategoryMask = categoryMask;
    }
    
    @Override
    public void HandleSitation(TrafficInfo situation) {
        String externalId = situation.getExternalId();
        InfoDbAdapter.SituationStatus currentStatus = mDbAdapter.findCurrentStatus(externalId);
        
        ReadState newState;
        if (currentStatus == null){
            newState = ReadState.New;
            addToChangedListIfMatch(situation);
        } else {
            ReadState lastReadState = currentStatus.getReadState();
        
            if (lastReadState == ReadState.New || lastReadState == ReadState.Modified){
                newState = lastReadState;
                // TODO: if timestamp is newer we might want to notify the user again
            } else {
                long lastTimeStamp = currentStatus.getTimeStamp().getTime();
              
                if (lastTimeStamp < situation.getModified().getTime()){
                    newState = ReadState.Modified;
                    addToChangedListIfMatch(situation);
                }
                else
                    newState = lastReadState;    
            }
        }
        
        Log.d(LOGTAG,"Setting readstate for situation '" + externalId + "' to " + newState.toString());
        situation.setState(newState);
        mDbAdapter.InsertOrUpdateInfo(situation);
    }
    
    private void addToChangedListIfMatch(TrafficInfo situation){
        if ((situation.getCategory() & mCategoryMask) != 0)
            mChangesIdsList.add(situation.getExternalId());
    }
    
    public  List<String> getChangedIds(){
        return mChangesIdsList;
    }
}
