package se.peterbjorkman.android.trafikinfo;

import java.util.List;

import android.content.res.Resources;
import android.database.Cursor;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapView;
import com.google.android.maps.MyLocationOverlay;
import com.google.android.maps.Overlay;

public abstract class SituationMapActivity extends MapActivity{
    private static final String LOGTAG = SituationMapActivity.class.getName();
    private MyLocationOverlay mMyLocationOverlay;
    private SituationMapOverlay mItemizedoverlay;
    MapView mMapView;
   
    private static final int MYLOCATION_MENU_ID = Menu.FIRST + 100;
    protected static final int LAST_MENU_ID_USED = MYLOCATION_MENU_ID;
    
    private static final int MESSAGE_FIXED_LOCATION = 1;
    
    public void onCreate(Bundle savedInstanceState) {
        Log.d(LOGTAG, "In onCreate");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.map_overview);

        mMapView = (MapView) findViewById(R.id.mapview);
        mMapView.setBuiltInZoomControls(true);
        
        List<Overlay> mapOverlays = mMapView.getOverlays();
        Drawable drawable = this.getResources().getDrawable(R.drawable.icon);
        mItemizedoverlay = new SituationMapOverlay(drawable);
        
        addSituationMarkers();

        mMyLocationOverlay = new MyLocationOverlay(getApplicationContext(), mMapView);
        mMyLocationOverlay.runOnFirstFix(new Runnable() {
            
            @Override
            public void run() {
                Message m = new Message();
                m.what = MESSAGE_FIXED_LOCATION;
                viewUpdateHandler.sendMessage(m);
            }
        });
        
        mapOverlays.add(mItemizedoverlay);
        mapOverlays.add(mMyLocationOverlay);
    }
    
    /** Message handler for messages from background threads. */
    Handler viewUpdateHandler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            
              Log.d(LOGTAG, "In handleMessage msg.what = " + msg.what);
              
            switch (msg.what) {

            case MESSAGE_FIXED_LOCATION:
                onFixedLocation();
                return;
            }
            Log.d(LOGTAG, "Message not handled in handleMessage. msg.what = " + msg.what);
            super.handleMessage(msg);
        }
    };

    protected void onFixedLocation() {
        panToCurrentLocation();
    }

    protected void addSituationMarkers() {
        SituationMapOverlay itemizedoverlay = mItemizedoverlay;

        itemizedoverlay.clearOverlays();
        
        InfoDbAdapter dbAdapter = new InfoDbAdapter(this);
        dbAdapter.open();
        Cursor cursor = getCursor(dbAdapter);
        Resources resources = getResources();
        
        while (cursor.moveToNext()){
            Double longitude = cursor.getDouble(cursor.getColumnIndexOrThrow(InfoDbAdapter.KEY_LONGITUDE));
            Double latitude  = cursor.getDouble(cursor.getColumnIndexOrThrow(InfoDbAdapter.KEY_LATITUDE));
            int id           = cursor.getInt(cursor.getColumnIndexOrThrow(InfoDbAdapter.KEY_ID));
            int type         = cursor.getInt(cursor.getColumnIndexOrThrow(InfoDbAdapter.KEY_TYPE));
            
            addSituation(itemizedoverlay, resources, longitude, latitude, id, type);
        }
        
        cursor.close();
        dbAdapter.close();
    }

    protected void addSituation(
            SituationMapOverlay itemizedoverlay,
            Resources resources, 
            Double longitude, 
            Double latitude, 
            int id,
            int type) {
        
        Drawable icon = resources.getDrawable(TrafficInfo.getIconResourceByType(type));
        SituationOverlayItem overlayitem = new SituationOverlayItem(id, longitude, latitude, icon);
        
        itemizedoverlay.addOverlay(overlayitem);
    }

    protected abstract Cursor getCursor(InfoDbAdapter dbAdapter);
    
    private void panToCurrentLocation(){
        GeoPoint point = mMyLocationOverlay.getMyLocation();
        if (point != null)
            setCenter(point);
        // TODO else toast??
    }

    protected void setCenter(GeoPoint point) {
        mMapView.getController().setCenter(point);
    }

    protected void zoomToSpan(int latSpanE6, int lonSpanE6) {
        mMapView.getController().zoomToSpan(latSpanE6, lonSpanE6);
    }

    @Override
    protected void onResume(){
        super.onResume();
        
        mMyLocationOverlay.enableCompass();
        mMyLocationOverlay.enableMyLocation();
    }
    
    @Override
    protected void onPause(){
        super.onPause();

        mMyLocationOverlay.disableCompass();
        mMyLocationOverlay.disableMyLocation();
    }
    
    @Override
    protected boolean isRouteDisplayed() {
        return false;
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        Log.d(LOGTAG, "In onCreateOptionsMenu");
        
        boolean result = super.onCreateOptionsMenu(menu);

        menu.add(0, MYLOCATION_MENU_ID, 0, R.string.myLocation)
            .setIcon(android.R.drawable.ic_menu_mylocation);
        
        return result;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        Log.d(LOGTAG, "In onOptionsItemSelected");
        
        switch (item.getItemId()) {
        case MYLOCATION_MENU_ID:
            panToCurrentLocation();
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
    
    protected SituationMapOverlay getItemizedoverlay(){
        return mItemizedoverlay;
    }
    
    protected MyLocationOverlay getMyLocationOverlay(){
        return mMyLocationOverlay;
    }
}
