package se.peterbjorkman.android.trafikinfo;

import java.util.ArrayList;
import android.graphics.drawable.Drawable;
import android.util.Log;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.ItemizedOverlay;

public class SituationMapOverlay extends ItemizedOverlay<SituationOverlayItem>{
    private static final String LOGTAG = SituationMapOverlay.class.getName();
    
    private ArrayList<SituationOverlayItem> mOverlays = new ArrayList<SituationOverlayItem>();
    
    int minLat  = Integer.MAX_VALUE;
    int minLong = Integer.MAX_VALUE;
    int maxLat  = Integer.MIN_VALUE;
    int maxLong = Integer.MIN_VALUE;
    
    public SituationMapOverlay(Drawable defaultMarker) {
        super(boundCenter(defaultMarker));
    }
    
    public void clearOverlays(){
        mOverlays.clear();
        populate();
    }

    public void addOverlay(SituationOverlayItem overlay) {
        mOverlays.add(overlay);
        int longitude = overlay.getPoint().getLongitudeE6();
        int latitude  = overlay.getPoint().getLatitudeE6();
        
        if (longitude < minLong)
            minLong = longitude;
        
        if (longitude > maxLong)
            maxLong = longitude;
        
        if (latitude < minLat)
            minLat = latitude;
        
        if (latitude > maxLat)
            maxLat = latitude;
        
        populate();
    }
    
    @Override
    protected SituationOverlayItem createItem(int i) {
        return mOverlays.get(i);
    }

    @Override
    public int size() {
        return mOverlays.size();
    }
    
    public interface OnTapListener{
        public void onTap(SituationOverlayItem item);
    }
    
    private OnTapListener mTapListener = null;
    
    public void setOnTapListener(OnTapListener listener){
        mTapListener = listener;
    }
    
    @Override
    protected boolean onTap(int index) {
        Log.d(LOGTAG, "in onTap");
        if  (mTapListener != null){
            SituationOverlayItem item =  mOverlays.get(index);
            Log.d(LOGTAG, "in onTap calling mTapListener.onTap");
            mTapListener.onTap(item);
            return true;
        }
        return false;
    }
    
    public static Drawable boundCenter(Drawable drawable){
        return ItemizedOverlay.boundCenter(drawable);
    }
    
    @Override
    public GeoPoint getCenter() {
        if (minLat  == Integer.MAX_VALUE ||
            minLong == Integer.MAX_VALUE ||
            maxLat  == Integer.MIN_VALUE ||
            maxLong == Integer.MIN_VALUE)
            return null;
        return new GeoPoint((maxLat + minLat) / 2, (maxLong + minLong) / 2);
    }
}
