/*
    This source file is part of the trafikinfo for android project
    Copyright (C) 2009-2010  Peter Björkman


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package se.peterbjorkman.android.trafikinfo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class TrafficInfo implements Serializable{

	private static final long serialVersionUID = 1601642220828054143L;
	
    private final String mHeader;
    private final String mTypeName;
    private final String mLocation;
    private final Date mFrom;
    private final Date mTo;
    private final String mExternalId;
    private final int mType;
    private final String mSource;
    private final String mRoad;
    private final Date mModified;
    private final Double mLongitude;
    private final Double mLatitude;
    private final List<String> mComments;
    private final List<Restriction> mRestricions;
    private ReadState mReadState;
    private final int mCategory;
	
    public TrafficInfo(
            String externalId,
            String header, 
            int type,
            int category,
            String typeName,
            String source, 
            String location,
            String road,
            Date modified,
            Double longitude,
            Double latitude,
            Date from, 
            Date to,
            ReadState readState,
            List<String> comments,
            List<Restriction> restrictions){
        mExternalId = externalId;
		mHeader = header;
		mTypeName = typeName;
		mLocation = location;
		mFrom = from;
		mTo = to;
	    mType = type;
	    mSource = source;
	    mRoad = road;
	    mModified = modified;
	    mLongitude = longitude;
	    mLatitude = latitude;
	    mComments = comments;
	    mRestricions = restrictions;
	    mReadState = readState;
	    mCategory = category;
	}
	
    public String getExternalId(){
        return mExternalId;
    }
    
	public String getHeader(){
		return mHeader;
	}
	
	public String getTypeName(){
		return mTypeName;
	}

	public String getLocation() {
		return mLocation;
	}

	public Date getFrom() {
		return mFrom;
	}

	public Date getTo() {
		return mTo;
	}
	
	   public int getType() {
	        return mType;
	    }

    public int getCategory() {
        return mCategory;
    }

    public String getSource() {
        return mSource;
    }

    public String getRoad() {
        return mRoad;
    }

    public Date getModified() {
        return mModified;
    }

    public Double getLongitude() {
        return mLongitude;
    }

    public Double getLatitude() {
        return mLatitude;
    }

    public List<String> getComments() {
        return mComments;
    }

    public List<Restriction> getRestricions() {
        return mRestricions;
    }
    
    public ReadState getState() {
        return mReadState;
    }    
    
    public void setState(ReadState state) {
        mReadState = state;
    }

    public enum ReadState{
        Unknown,
        New,
        Modified,
        Read,
        UserDeleted,
    }
    
    public String getHeaderWithRoadname()
    {
        return getHeaderWithRoadName(mHeader, mRoad);
    }
    
    public static String getHeaderWithRoadName(String header, String roadname){
        if (!header.contains(roadname))
            header = roadname + " - " + header;
        return header;          
    }
    
    private static final int ROADWORKS                    = 0x00000302;
    private static final int ROADWORKS_MASK               = 0x0000FFFF;
    private static final int ABNORMALTRAFFIC              = 0x00000103;
    private static final int ABNORMALTRAFFIC_MASK         = 0x0000FFFF;
    private static final int ACCIDENT                     = 0x00000203;
    private static final int ACCIDENT_MASK                = 0x0000FFFF;
    private static final int ROADSURFACEINPOORCONDITION   = 0x09020403;
    private static final int ROADSURFACEINPOORCONDITION_M = 0xFFFFFFFF;
    private static final int WHETERROADCONDITIONS         = 0x02030403;
    private static final int WHETERROADCONDITIONS_MASK    = 0xFFFFFFFF;
    private static final int ROADCONDITIONS               = 0x00020403;
    private static final int ROADCONDITIONS_MASK          = 0x00FFFFFF;
    private static final int ANIMALPRESENCEOBSTRUCTION    = 0x00010503;
    private static final int ANIMALPRESENCEOBSTRUCTION_M  = 0x00FFFFFF;
    private static final int OBSTRUCTION                  = 0x00000503;
    private static final int OBSTRUCTION_MASK             = 0x0000FFFF;
    private static final int TEMPORARYSPEEDLIMIT          = 0x02120102;
    private static final int TEMPORARYSPEEDLIMIT_MASK     = 0xFFFFFFFF;
    private static final int REROUTING                    = 0x01120102;
    private static final int REROUTING_MASK               = 0xFFFFFFFF;
    private static final int ROADCLOSED                   = 0x000E0102;
    private static final int ROADCLOSED_MASK              = 0xFFFFFFFF;
    
    // TODO Get By category
    public static int getIconResourceByType(int type){
        if ((type & ROADWORKS_MASK) == ROADWORKS)
            return R.drawable.roadworks36;
        else if ((type & ANIMALPRESENCEOBSTRUCTION_M) == ANIMALPRESENCEOBSTRUCTION)
                return R.drawable.moose_warning36;
        else if ((type & ABNORMALTRAFFIC_MASK) == ABNORMALTRAFFIC)
            return R.drawable.queue36;
        else if ((type & ACCIDENT_MASK) == ACCIDENT)
            return R.drawable.accident36;
        else if ((type & ROADSURFACEINPOORCONDITION_M) == ROADSURFACEINPOORCONDITION)
            return R.drawable.road_surface_in_poor_condition36;
        else if ((type & WHETERROADCONDITIONS_MASK) == WHETERROADCONDITIONS)
            return R.drawable.road_conditions36;
        else if ((type & ROADCONDITIONS_MASK) == ROADCONDITIONS)
                return R.drawable.road_conditions36;
        else if ((type & OBSTRUCTION_MASK) == OBSTRUCTION)
            return R.drawable.other_dangers36;
        else if ((type & TEMPORARYSPEEDLIMIT_MASK) == TEMPORARYSPEEDLIMIT)
            return R.drawable.speedlimit36;
        else if ((type & REROUTING_MASK) == REROUTING)
            return R.drawable.rerouting40;
        else if ((type & ROADCLOSED_MASK) == ROADCLOSED)
            return R.drawable.road_closed36;
        else 
            return R.drawable.information36;
    }
}
