package se.peterbjorkman.android.trafikinfo;

import java.util.Date;
import java.util.List;

import se.peterbjorkman.android.trafikinfo.Exceptions.FetchInfoException;

public class TrafikInfoNuCoordFetcher extends TrafikInfoNuInfoFetcher implements IDataFetcher {

    private final Double mLongMin; 
    private final Double mLongMax; 
    private final Double mLatMin;
    private final Double mLatMax;
    private final Double mpLongMin; 
    private final Double mpLongMax; 
    private final Double mpLatMin;
    private final Double mpLatMax;
    
    public TrafikInfoNuCoordFetcher(
            String deviceId, 
            int versioCode,
            Double longMin, 
            Double longMax, 
            Double latMin, 
            Double latMax, 
            Double plongMin, 
            Double plongMax, 
            Double platMin, 
            Double platMax) {
        super(deviceId, versioCode);
        mLongMin = longMin; 
        mLongMax = longMax; 
        mLatMin  = latMin;
        mLatMax  = latMax;
        mpLongMin = plongMin; 
        mpLongMax = plongMax; 
        mpLatMin  = platMin;
        mpLatMax  = platMax;
    }

    @Override
    public List<String> getIdsNewerThan(Date onlyNewerThan)
            throws FetchInfoException {
        String url = "http://api.trafikinfo.nu/listByCoordinates.php";
        url += "?longMax=" + mLongMax;
        url += "&longMin=" + mLongMin;
        url += "&latMin="  + mLatMin;
        url += "&latMax="  + mLatMax;
        
        if (onlyNewerThan != null){
            url += "&plongMax=" + mpLongMax;
            url += "&plongMin=" + mpLongMin;
            url += "&platMin="  + mpLatMin;
            url += "&platMax="  + mpLatMax;    
        }
        
        return getIdsByUrl(onlyNewerThan, url);
    }

    @Override
    public void getSituations(Date modifiedSince,
            ISituationHandler handler) throws FetchInfoException {
        String url = "http://api.trafikinfo.nu/getSituationsByCoordinates.php?lang=sv-SE";
        url += "&longMax=" + mLongMax;
        url += "&longMin=" + mLongMin;
        url += "&latMin="  + mLatMin;
        url += "&latMax="  + mLatMax;
        
        if (modifiedSince != null){
            url += "&plongMax=" + mpLongMax;
            url += "&plongMin=" + mpLongMin;
            url += "&platMin="  + mpLatMin;
            url += "&platMax="  + mpLatMax;    
        }
        
        getSituationsByUrl(modifiedSince, handler, url); 
    }

}
