package se.peterbjorkman.android.trafikinfo;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.pm.PackageManager.NameNotFoundException;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

public class WelcomeDialogBuilder {
    private static final String LOGTAG = WelcomeDialogBuilder.class.getName();
    
    private final Context mContext;

    public  WelcomeDialogBuilder(Context context){
        mContext = context;
    }
    
//    private String getString(int id){
//        return mContext.getString(id);
//    }
    
    public Dialog getWelcomeDialog(){
        AlertDialog.Builder d = new AlertDialog.Builder(mContext);
        long lastVersion = getLastVersionCode(mContext);
        d.setIcon(android.R.drawable.ic_menu_info_details);

        if (lastVersion == 0)
            d.setTitle("Välkommen");
        else
            d.setTitle("Nyheter");
        
        d.setNegativeButton("Ok", new OnClickListener() {
            
            @Override
            public void onClick(DialogInterface dialog, int which) {
                long currentVersion = getCurrentVersionCode(mContext);
                InfoDbAdapter dbAdapter = new InfoDbAdapter(mContext);
                dbAdapter.open();
                dbAdapter.setLastVersion(currentVersion);
                dbAdapter.close();
            }
        });
        
        View v = LayoutInflater.from(mContext).inflate(R.layout.welcome, null);
       
        ViewGroup layout = (ViewGroup)v.findViewById(R.id.LinearLayout01);
        addMessageToLayout(lastVersion, layout);
        d.setView(v);

        Log.d(LOGTAG, "Returning from onCreateDialog");
        
        return d.create();
    }
    
    private void addMessageToLayout(long lastVersion, ViewGroup layout) {
        TextView textView = (TextView)layout.findViewById(R.id.TextView01);

        Context context = mContext;
        if (lastVersion == 0)
            addInstallInfo(layout, textView, context);
        else
            addUpgradeInfo(lastVersion, layout, textView, context);

        InfoBlock webPage = addTextBlock(
                layout, 
                context, 
                "Hemsida", 
                "För mer infomration om applikationen besök dess hemsida.");
        
        // TODO Why doesn't the links work
        //webPage.addExtraText("http://android.trafikinfo.nu", context, true);
        webPage.addExtraText("Hemsidan nås genom att trycka meny-knappen och välja 'Om'", context);
        webPage.addExtraText("Notera att applikationen är under utveckling och ny funktionalitet kommer löpande. (se hemsidan för mer info)", context);
        
    }

    private void addUpgradeInfo(long lastVersion, ViewGroup layout,
            TextView textView, Context context) {
        if (lastVersion <= 5){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Markering av olästa meddelanden i listan", 
                    "Nya/ändrade meddelanden visas överst i listan.");

            InfoBlock profiles = addTextBlock(
                    layout, 
                    context, 
                    "Profiler", 
                    "De nya begreppen 'Trafikäge' och 'Uppdateringsläge' ersätter de tidigare begreppen kort repektive långt uppdateringsintervall.");
            
            profiles.addExtraText("Trafikiäge är tänkt att används då du vill ha snabba uppdateringar och tydliga notifieringar medan du är ute och kör.", context);
            profiles.addExtraText("Uppdateringsläget är till för då du vill hålla dig uppdaterad men inte behöver lika frekventa uppdateringar och inte vil bli störd med notifieringar varje gång ett nytt meddelande kommer.", context);
    
            InfoBlock notifications = addTextBlock(
                    layout, 
                    context, 
                    "Notifieringar", 
                    "Du kan få notifieringar då nya meddelanden kommer eller meddelanden uppdateras.");
            
            notifications.addExtraText("Du kan ställa in olika typer av notifieringar beroende på vilken av profilerna du använder.", context);
        }
        
        if (lastVersion <= 6){    
            InfoBlock listOrder = addTextBlock(
                    layout, 
                    context, 
                    "Möjlighet att använda telefonenes position som område", 
                    "Meddelanden inom en angiven radie från aktuell position visas då detta val görs.");
            listOrder.addExtraText("Under Inställningar - Välj område kan \"Aktuell position\" väljas.", context);
            listOrder.addExtraText("Under Inställningar anges inom vilken radie från aktuell position man är intresserad av.", context);
            listOrder.addExtraText("Det går fOrtfarande bra att ange ett län som område.", context);
        }
        
        if (lastVersion <= 7){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Kartvisning", 
                    "I översiktsvyn kan nu alla meddelanden visas i en kartvy för bättre översikt.");
            
            addTextBlock(
                    layout, 
                    context, 
                    "Automatisk markering av meddelanden som lästa", 
                    "Då man lämnar översiktsvyn markeras automatiskt alla meddealanden som lästa. Menyvalet \"Markera alla som lästa\" har tagits bort.");
            
        }
        
        if (lastVersion <= 8){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Listning av planerade störningar", 
                    "Nu kan du även på en lista på framtida, planerade störningar såsom planerade vägarbeten.");
        }
        
        if (lastVersion <= 9){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Nytt utseende på widget", 
                    "Widgeten har fått ett nytt, modernare och snyggare utseende. (Tack till Manny på www.swedroid.se för grafiken.)");
            addTextBlock(
                    layout, 
                    context, 
                    "Enklare att växla profil från applikationens huvudvy.", 
                    "Nu finns valet profil i menyn i applikationens huvudvy för att möjliggöra snabb växling mellan profiler för de som inte använder widgeten.");
        }
        
        if (lastVersion <= 10){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Möjlighet att radera meddelanden.", 
                    "Du kan nu radera meddelanden genom att långtrycka på meddelanden i listor eller genom att trycka meny och välja \"Ta bort\" när du tittar på ett meddelandes detaljer.");
            addTextBlock(
                    layout, 
                    context, 
                    "GPS används endast om man så önskar.", 
                    "GPS:en används nu inte även om den är aktiverad i telefonen. Om du vill att applikationen ska använda GPS:en gå in under inställningar->Område och kryssa i \"Tillåt användning av GPS\".");
        }
        
        if (lastVersion <= 11){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Möjlighet att välja vilka kategorier av meddelanden man vill se.", 
                    "Du kan nu kryssa i vilka kategorier du är intresserad av. Gå in i Inställningar->Kategorier.");
            addTextBlock(
                    layout, 
                    context, 
                    "Ikoner visas i listan.", 
                    "För lättare översikt i listan visas nu ikoner efter typ.");
        }
        
        if (lastVersion == 12){
            textView.setVisibility(View.GONE);
            addTextBlock(
                    layout, 
                    context, 
                    "Buggfix.", 
                    "Fixat problem vid uppdatering av widget.");
        }
    }

    private void addInstallInfo(ViewGroup layout, TextView textView,
            Context context) {
        String message = "Du har nu installerat TrafikInfo.nu.";
        textView.setText(message);

        addTextBlock(
                layout, 
                context, 
                "Kom i gång", 
                "För att hämta trafikmeddelanden i applikationen tryck på telefonens meny-knapp och välj uppdatera.");
        
        InfoBlock settings = addTextBlock(
                layout, 
                context, 
                "Inställningar", 
                "För att ställla in för vilket område du vill ha meddelanden för tryck på meny-knappen och välj Inställningar följt av Område.");
        
        settings.addExtraText("Där kan du välja aktuell postion eller ett visst län. Väljer du aktuell position visas alla meddelanden inom en angiven radie från telefonenes position.", context);
        
        settings.addExtraText("Under Inställningar hittar du även inställningar för automatiska uppdateringar och inställningar för notifieringar vid nya/ändrade meddelanden.", context);
        
        addTextBlock(
                layout, 
                context, 
                "Markering av olästa meddelanden i listan", 
                "Nya/ändrade meddelanden visas överst i listan.");

        InfoBlock profiles = addTextBlock(
                layout, 
                context, 
                "Profiler", 
                "Du kan använda dig av tre olika profiler för automatiska uppdateringar. 'Manuella uppdateringar', 'Trafikläge' eller 'Uppdateringsläge'.");
        
        profiles.addExtraText("Trafikläge är tänkt att används då du vill ha snabba uppdateringar och tydliga notifieringar medan du är ute och kör.", context);
        profiles.addExtraText("Uppdateringsläget är till för då du vill hålla dig uppdaterad men inte behöver lika frekventa uppdateringar och inte vil bli störd med notifieringar varje gång ett nytt meddelande kommer.", context);
   
        InfoBlock notifications = addTextBlock(
                layout, 
                context, 
                "Notifieringar", 
                "Du kan få notifieringar då nya meddelanden kommer eller meddelanden uppdateras.");
        
        notifications.addExtraText("Du kan ställa in olika typer av notifieringar beroende på vilken av profilerna du använder.", context);
    }

    private InfoBlock addTextBlock(ViewGroup layout, Context context, String title, String message) {
        InfoBlock newBlock = new InfoBlock(context);
        newBlock.setTitleText(title);
        newBlock.setInfoText(message);
        layout.addView(newBlock);
        return newBlock;
    }

    public static Boolean ShouldBeShown(Context context){
        Log.d(LOGTAG, "In ShouldBeShown");
        return getCurrentVersionCode(context) > getLastVersionCode(context);
    }
    
    public static int getCurrentVersionCode(Context context) {
        Log.d(LOGTAG, "In getCurrentVersionCode");
        try {
            return context.getPackageManager().getPackageInfo(context.getPackageName(), 0).versionCode;
        } catch (NameNotFoundException e) {
            Log.e(LOGTAG, "NameNotFoundException in  getVersion " + e.getLocalizedMessage());
            // Ignore.
        }
        Log.w(LOGTAG, "Returning 0 from getCurrentVersionCode");
        return 0;
    }
    
    private static long getLastVersionCode(Context context) {
        Log.d(LOGTAG, "In getLastVersionCode");
        InfoDbAdapter dbAdapter = new InfoDbAdapter(context);
        dbAdapter.open();
        long val = dbAdapter.getLastVersion();
        dbAdapter.close();
        return val;
    }
}
